## Summary

<!-- Brief description of what this PR does. -->

## Type of change

- [ ] Bug fix (non-breaking change that fixes an issue)
- [ ] New feature / new indicator (non-breaking change)
- [ ] Breaking change (fix or feature that changes existing behaviour)
- [ ] Documentation / infrastructure only

## Checklist

- [ ] All existing tests pass (`pytest tests/`)
- [ ] New tests have been added for any new behaviour
- [ ] `cargo fmt --check` passes
- [ ] `cargo clippy --release -- -D warnings` passes
- [ ] README accuracy table updated (if indicators were added or changed)
- [ ] CHANGELOG.md updated (for user-visible changes)
- [ ] Docstrings added or updated for new/changed public functions

## Related Issues

Closes #<!-- issue number -->
